import attr
from bs4 import Tag


@attr.dataclass(slots=True)
class KelulusanSertifikasi:
    nama: str
    tanggal_lahir: str
    nuptk: str
    nrg: str
    nomor_peserta: str
    nomor_sertifikat: str
    kode_sertifikasi_pertama: str
    nama_bidang_studi_sertifikasi: str
    nama_sekolah_terbit_nrg: str
    data_tercatat_jenjang: str
    kab_kota_saat_ini: str

    @classmethod
    def from_fit_kelulusan(cls, tag: Tag) -> "KelulusanSertifikasi":
        # #fit_Kelulusan
        pass



#!/usr/bin/env python

import attr
import logging
from bs4 import BeautifulSoup
from requests import Session
from typing import Optional

from . import DataIndividu
from . import StatusNuptk
from .table_data import TableData


@attr.dataclass(slots=True)
class LoginData:
    userid: str
    password: str
    submit: str = "Login"
    mod: str = "cek_guru"
    metode: str = "Account"
    s: str = "990"


@attr.dataclass
class InfoGtk:
    email: str
    password: str
    base_url: str = "https://info.gtk.kemdikbud.go.id/"

    def __attrs_post_init__(self):
        self._logger = logging.getLogger(self.__class__.__name__)
        self._session = Session()
        self._dashboard = ""
        self._soup: Optional[BeautifulSoup] = None
        self._data_individu: Optional[DataIndividu] = None
        self._status_nuptk: Optional[StatusNuptk] = None
        self._verify = False
        self.is_login = False
        if not self.is_login:
            self.is_login = self.login()
        if not self._dashboard:
            self._dashboard = self.get_dashboard()

    @property
    def dashboard(self) -> str:
        if not self._dashboard:
            while not self._dashboard:
                self._dashboard = self.get_dashboard()
        return self._dashboard

    @property
    def soup(self) -> BeautifulSoup:
        if self._soup:
            return self._soup
        self._soup = BeautifulSoup(self.dashboard, "html.parser")
        return self._soup

    @property
    def data_individu(self) -> DataIndividu:
        if self._data_individu:
            return self._data_individu
        table_data = TableData.make_individu(self.dashboard)
        self._data_individu = DataIndividu.from_table_datas(table_data)
        return self._data_individu

    @property
    def status_nuptk(self) -> StatusNuptk:
        if self._status_nuptk:
            return self._status_nuptk
        table_data = TableData.make_status_nuptk(self.dashboard)
        self._status_nuptk = StatusNuptk.from_table_data(table_data)
        return self._status_nuptk

    def login(self, email: str = None, password: str = None, retry=0) -> bool:
        email = email or self.email
        password = password or self.password
        if self.is_login:
            self.logout()
        self._logger.debug("Getting login page")
        res = self._session.get(self.base_url + "/?s=999&pesan=", verify=self._verify)
        if not res.ok:
            self._logger.debug("Getting login page failed")
            if retry > 0:
                return self.login(email, password, retry)
            return False
        # Capthca
        data = LoginData(userid=email, password=password)
        headers = {"Referer": res.url}
        self._logger.debug("Trying to login")
        res = self._session.post(
            self.base_url,
            data=attr.asdict(data),
            allow_redirects=False,
            headers=headers,
            verify=self._verify,
        )
        if not res.status_code == 302:
            self._logger.debug("Login failed")
            if retry > 0:
                return self.login(email, password, retry)
            return False
        self._logger.debug("Login success")
        return res.status_code == 302

    def get_dashboard(self) -> str:
        res = self._session.get(self.base_url + "dashboard", verify=self._verify)
        if res.status_code != 404 or not res.text:
            return ""
        return res.text

    def logout(self) -> bool:
        res = self._session.get(self.base_url + "auth/logout", verify=self._verify)
        return res.ok



import attr

from info_gtk.table_data import TableData


@attr.dataclass(slots=True)
class SekolahInduk:
    nama: str
    validasi: str
    terdeteksi: str
    keterangan_validasi: str

    @classmethod
    def from_table_data(cls, table_data: TableData) -> "SekolahInduk":
        data = table_data.children
        return cls(
            nama=data[0].data,
            validasi=data[1].data,
            terdeteksi=data[2].data,
            keterangan_validasi=data[3].data,
        )


@attr.dataclass(slots=True)
class LokasiSekolahInduk:
    provinsi: str
    kab_kota: str
    kecamatan: str
    desa_kelurahan: str
    kategori_desa_kelurahan: str

    @classmethod
    def from_table_data(cls, table_data: TableData) -> "LokasiSekolahInduk":
        data = table_data.children
        return cls(
            provinsi=data[0].data,
            kab_kota=data[1].data,
            kecamatan=data[2].data,
            desa_kelurahan=data[3].data,
            kategori_desa_kelurahan=data[4].data,
        )



import attr
from bs4 import Tag


@attr.dataclass(slots=True)
class Profile:
    nama: str
    ttl: str
    pendidikan: str
    sekolah_induk: str
    email: str
    email_terverifikasi: bool
    alamat: str

    @classmethod
    def from_panel(cls, tag: Tag) -> "Profile":
        # /html/body/div[2]/div[2]/div[1]/div[1]/div
        pass



#!/usr/bin/env python
from .data_individu import DataIndividu
from .status_nuptk import StatusNuptk
from .kelulusan_sertifikasi import KelulusanSertifikasi
from .realisasi_sktp import RealisasiSktp
from .profile import Profile
from .rombongan_belajar import RombonganBelajar
from .sktp import Sktp
from .verivikasi_data_tunjangan import VerivikasiDataTunjangan


from .info_gtk import InfoGtk

from .version import __version__  # NOQA

__author__ = "hexatester <habibrohman@protonmail.com>"

__all__ = [
    "DataIndividu",
    "StatusNuptk",
    "KelulusanSertifikasi",
    "RealisasiSktp",
    "Profile",
    "RombonganBelajar",
    "Sktp",
    "VerivikasiDataTunjangan",
    "InfoGtk",
]



import attr
from typing import Optional

from info_gtk.table_data import TableData


@attr.dataclass(slots=True)
class JamMengajarInduk:
    jam_mengajar: str
    jam_linier: str

    @classmethod
    def from_table_data(cls, table_data: TableData) -> "JamMengajarInduk":
        data = table_data.children
        return cls(
            jam_mengajar=data[0].data,
            jam_linier=data[1].data,
        )


@attr.dataclass(slots=True)
class JamMengajarNonInduk:
    jam_mengajar: Optional[str] = None
    jam_linier: Optional[str] = None

    @classmethod
    def from_table_data(cls, table_data: TableData) -> "JamMengajarNonInduk":
        data = table_data.children
        return cls(
            jam_mengajar=data[0].data if data[0].data else None,
            jam_linier=data[1].data if data[1].data else None,
        )


@attr.dataclass(slots=True)
class JamMengajarIndukNonInduk:
    total_mengajar: str
    total_linier: str

    @classmethod
    def from_table_data(cls, table_data: TableData) -> "JamMengajarIndukNonInduk":
        data = table_data.children
        return cls(
            total_mengajar=data[0].data,
            total_linier=data[1].data,
        )


@attr.dataclass(slots=True)
class JamMengajar:
    sekolah_induk: JamMengajarInduk
    sekolah_non_induk: JamMengajarNonInduk
    sekolah_induk_non_induk: JamMengajarIndukNonInduk

    @classmethod
    def from_table_data(cls, table_data: TableData) -> "JamMengajar":
        data = table_data.children
        return cls(
            sekolah_induk=JamMengajarInduk.from_table_data(data[0]),
            sekolah_non_induk=JamMengajarNonInduk.from_table_data(data[1]),
            sekolah_induk_non_induk=JamMengajarIndukNonInduk.from_table_data(data[2]),
        )



import attr
from bs4 import Tag


@attr.dataclass(slots=True)
class Sktp:
    nomor_sktp: str
    tanggal_penerbitan_sktp: str
    pembayaran_tpg_periode: str
    format_bayar: str
    nama_penerima: str
    nip: str
    nuptk: str
    nrg: str
    kab_kota: str
    provinsi: str
    rekening_bank: str

    @classmethod
    def from_fit_sktp(cls, tag: Tag) -> "Sktp":
        # #fit_SKTP
        pass



from .ijazah_terakhir import IjazahTerakhir
from .jam_mengajar import JamMengajar, JamMengajarInduk, JamMengajarNonInduk
from .sekolah_induk import SekolahInduk, LokasiSekolahInduk
from .status_kepegawaian import StatusKepegawaian
from .tugas_tambahan import TugasTambahan
from .data_individu import DataIndividu


__all__ = [
    "IjazahTerakhir",
    "JamMengajar",
    "JamMengajarInduk",
    "JamMengajarNonInduk",
    "SekolahInduk",
    "LokasiSekolahInduk",
    "StatusKepegawaian",
    "TugasTambahan",
    "DataIndividu",
]



import attr
import json5
from typing import List, Optional


@attr.dataclass
class TableData:
    no: str
    uraian: str
    data: str
    keterangan: str
    col: Optional[str] = None
    children: List["TableData"] = attr.ib(factory=list)

    @classmethod
    def from_json5_list(cls, datas: str) -> List["TableData"]:
        if not datas:
            return list()
        return cls.from_list(json5.loads(datas))

    @classmethod
    def from_list(cls, datas: List[dict]) -> List["TableData"]:
        results: List["TableData"] = list()
        for data in datas:
            children = data.pop("_children", None)
            if children:
                data["children"] = cls.from_list(children)
            results.append(cls(**data))
        return results

    @classmethod
    def make_individu(cls, data: str) -> List["TableData"]:
        tabledata: str = ""
        datas = data.splitlines()
        for i, line in enumerate(datas):
            if "/*individu*/" in line:
                tabledata = datas[i + 1]
                tabledata = tabledata.strip()
                tabledata = tabledata.lstrip("try {var tabledata = ")
                tabledata = tabledata.rstrip(
                    ';putTable("#fit_individu",tabledata);} catch(err) {  };'
                )
                break
        if not tabledata:
            return list()
        return cls.from_json5_list(tabledata)

    @classmethod
    def make_status_nuptk(cls, data: str) -> List["TableData"]:
        tabledata: str = ""
        datas = data.splitlines()
        for i, line in enumerate(datas):
            if "/*arsip NUPTK*/" in line:
                tabledata = datas[i + 1]
                tabledata = tabledata.strip()
                tabledata = tabledata.lstrip("try { var tabledata = ")
                tabledata = tabledata.rstrip(
                    ';putTable("#fit_ArsipNuptk",tabledata);} catch(err) {  };'
                )
                break
        if not tabledata:
            return list()
        return cls.from_json5_list(tabledata)



import attr
from bs4 import Tag
from typing import List


@attr.dataclass(slots=True)
class StatusRombonganBelajar:
    nama: str
    tingkat: str
    paralel: int
    kurikulum: str


@attr.dataclass(slots=True)
class MataPelajaranDiampu:
    kode: int
    nama: str
    linier: int


@attr.dataclass(slots=True)
class JumlahJamMengajar:
    kurikulum: int
    dapodik: int
    diakui: int
    linier: int


@attr.dataclass(slots=True)
class RombonganBelajar:
    no: int
    nama_sekolah: str
    status_rombongan_belajar: StatusRombonganBelajar
    semester: str
    mata_pelajaran_diampu: MataPelajaranDiampu
    jjm: JumlahJamMengajar
    jjm_rombel: int
    jumlah_siswa: int
    jenis_jam: str
    status: str
    keterangan: str

    @classmethod
    def from_fit_rombongan_belajar(cls, tag: Tag) -> List["RombonganBelajar"]:
        # #fit_RombonganBelajar
        pass



import attr

from info_gtk.table_data import TableData


@attr.dataclass(slots=True)
class TugasTambahan:
    nama: str
    sk: str
    tmt: str
    tst: str
    validasi: str
    jumlah_rombel: str
    jumlah_tt_diakui: str
    jumlah_tt_terdetejsi: str
    diakui_linier: str
    keterangan_validasi: str

    @classmethod
    def from_table_data(cls, table_data: TableData) -> "TugasTambahan":
        data = table_data.children
        return cls(
            nama=data[0].data,
            sk=data[1].data,
            tmt=data[2].data,
            tst=data[3].data,
            validasi=data[4].data,
            jumlah_rombel=data[5].data,
            jumlah_tt_diakui=data[6].data,
            jumlah_tt_terdetejsi=data[7].data,
            diakui_linier=data[8].data,
            keterangan_validasi=data[9].data,
        )



import attr
from typing import List

from info_gtk.table_data import TableData


@attr.dataclass(slots=True)
class StatusNuptk:
    nuptk: str
    nama: str
    tempat_lahir: str
    tanggal_lahir: str
    nama_ibu_kandung: str
    nip: str
    nik: str
    instansi: str
    kab_kota: str

    @classmethod
    def from_table_data(cls, table_data: List[TableData]) -> "StatusNuptk":
        return cls(
            nuptk=table_data[0].data,
            nama=table_data[1].data,
            tempat_lahir=table_data[2].data,
            tanggal_lahir=table_data[3].data,
            nama_ibu_kandung=table_data[4].data,
            nip=table_data[5].data,
            nik=table_data[6].data,
            instansi=table_data[7].data,
            kab_kota=table_data[8].data,
        )



import attr

from info_gtk.table_data import TableData


@attr.dataclass(slots=True)
class StatusKepegawaian:
    nama: str
    nipy: str
    sk_pengangkatan: str
    tmt_pengangkatan: str
    sumber_gaji: str
    status_inpassing: str

    def __str__(self) -> str:
        return self.nama

    @classmethod
    def from_table_data(cls, table_data: TableData) -> "StatusKepegawaian":
        data = table_data.children
        return cls(
            nama=data[0].data,
            nipy=data[1].data,
            sk_pengangkatan=data[2].data,
            tmt_pengangkatan=data[3].data,
            sumber_gaji=data[4].data,
            status_inpassing=data[5].data,
        )



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['info_gtk', 'info_gtk.data_individu']

package_data = \
{'': ['*']}

install_requires = \
['attrs>=20.3.0,<21.0.0',
 'bs4>=0.0.1,<0.0.2',
 'click>=7.1.2,<8.0.0',
 'json5>=0.9.5,<0.10.0',
 'openpyxl>=3.0.5,<4.0.0',
 'requests>=2.25.0,<3.0.0']

setup_kwargs = {
    'name': 'info-gtk',
    'version': '0.2.0',
    'description': 'CLI / SDK python info-gtk',
    'long_description': '# Info GTK CLI\n\n[![PyPi Package Version](https://img.shields.io/pypi/v/info-gtk)](https://pypi.org/project/info-gtk/)\n[![Supported Python versions](https://img.shields.io/pypi/pyversions/info-gtk)](https://pypi.org/project/info-gtk/)\n[![LICENSE](https://img.shields.io/github/license/dapodix/info-gtk)](https://github.com/dapodix/info-gtk/blob/main/LICENSE)\n[![Tests](https://github.com/dapodix/info-gtk/workflows/Tests/badge.svg)](https://github.com/dapodix/info-gtk/actions?query=workflow%3ATests)\n[![codecov](https://codecov.io/gh/dapodix/info-gtk/branch/main/graph/badge.svg)](https://codecov.io/gh/dapodix/info-gtk)\n\nCLI / SDK python [info-gtk](https://info.gtk.kemdikbud.go.id/).\n\n## Fitur yang akan datang\n\nBerikut fitur yang akan direncanakan untuk aplikasi ini.\n\n- Export data ke excel\n- Download / Print masal\n\n## Donasi\n\nJika anda ingin melakukan donasi untuk kami, bisa menghubungi kami melalui [WhatsApp](https://wa.me/6287725780404) ataupun [Telegram](https://t.me/hexatester).\n\n## Legal / Hukum\n\nKode ini sama sekali tidak berafiliasi dengan, diizinkan, dipelihara, disponsori atau didukung oleh Kemdikbud atau afiliasi atau anak organisasinya. Ini adalah perangkat lunak yang independen dan tidak resmi. _Gunakan dengan risiko Anda sendiri_.\n',
    'author': 'hexatester',
    'author_email': 'habibrohman@protonmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6.1,<4.0.0',
}


setup(**setup_kwargs)



import attr
from bs4 import Tag


@attr.dataclass(slots=True)
class VerivikasiDataTunjangan:
    nuptk: bool
    keterangan_nuptk: str
    beban_mengajar: bool
    keterangan_beban_mengajar: str
    kelengkapan_data: bool
    keterangan_kelengkapan_data: str
    kelulusan_sertifikasi: bool
    keterangan_kelulusan_sertifikasi: str
    keaktifan: bool
    keterangan_keaktifan: str
    kepegawaian: bool
    keterangan_kepegawaian: str
    usia: bool
    keterangan_usia: str

    @classmethod
    def from_fit_verivikasi(cls, tag: Tag) -> "VerivikasiDataTunjangan":
        # #fit_Verifikasi
        pass



import attr

from info_gtk.table_data import TableData


@attr.dataclass(slots=True)
class IjazahTerakhir:
    nama: str
    jurusan: str
    perguruan: str

    @classmethod
    def from_table_data(cls, table_data: TableData) -> "IjazahTerakhir":
        data = table_data.children
        return cls(
            nama=data[0].data,
            jurusan=data[1].data,
            perguruan=data[2].data,
        )



import attr
from bs4 import Tag
from typing import List


@attr.dataclass(slots=True)
class PeriodePembayaran:
    tw: int
    bulan: str


@attr.dataclass(slots=True)
class BankPenyalur:
    nomor_rekening: str
    nama_pemegang_rekening: str
    nama_bank: str
    cabang_bank: str


@attr.dataclass(slots=True)
class RealisasiSktp:
    no: int
    periode: PeriodePembayaran
    bank_penyalur: BankPenyalur

    @classmethod
    def from_fit_realisasi_sktp(cls, tag: Tag) -> List["RealisasiSktp"]:
        # #fit_RealisasiBayarSKTP
        pass



import attr
from typing import List

from info_gtk.table_data import TableData
from . import IjazahTerakhir
from . import JamMengajar
from . import SekolahInduk, LokasiSekolahInduk
from . import StatusKepegawaian
from . import TugasTambahan


@attr.dataclass(slots=True)
class DataIndividu:
    update_terakhir: str
    nuptk: str
    nama: str
    tanggal_lahir: str
    nik: str
    email: str
    tanggal_pensiun: str
    jenis_ptk: str
    status_kepegawaian: StatusKepegawaian
    ijazah_terakhir: IjazahTerakhir
    sekolah_induk: SekolahInduk
    lokasi_sekolah_induk: LokasiSekolahInduk
    tugas_tambahan: TugasTambahan
    jumlah_jam_mengajar: JamMengajar
    total_jjm_linier_tambahan: str

    @classmethod
    def from_table_datas(cls, table_data: List[TableData]) -> "DataIndividu":
        # #fit_individu
        return cls(
            update_terakhir=table_data[0].data,
            nuptk=table_data[1].data,
            nama=table_data[2].data,
            tanggal_lahir=table_data[3].data,
            nik=table_data[4].data,
            email=table_data[5].data,
            tanggal_pensiun=table_data[6].data,
            jenis_ptk=table_data[7].data,
            status_kepegawaian=StatusKepegawaian.from_table_data(table_data[8]),
            ijazah_terakhir=IjazahTerakhir.from_table_data(table_data[9]),
            sekolah_induk=SekolahInduk.from_table_data(table_data[10]),
            lokasi_sekolah_induk=LokasiSekolahInduk.from_table_data(table_data[11]),
            tugas_tambahan=TugasTambahan.from_table_data(table_data[12]),
            jumlah_jam_mengajar=JamMengajar.from_table_data(table_data[13]),
            total_jjm_linier_tambahan=table_data[14].data,
        )
